pub struct ImpulsiveManeuver {
pub local_frame: LocalFrame,
pub dv_km_s: Vector3<f64>,
}Expand description
Impulsive maneuver defines an instantaneous state change which causes a discontinuity in the trajectory. While useful for preliminary design, it is not typically relevant for spaceflight operations
Fields
local_frame: LocalFramedv_km_s: Vector3<f64>Trait Implementations
Sourceimpl Clone for ImpulsiveManeuver
impl Clone for ImpulsiveManeuver
Sourcefn clone(&self) -> ImpulsiveManeuver
fn clone(&self) -> ImpulsiveManeuver
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImpulsiveManeuver
impl Debug for ImpulsiveManeuver
Sourceimpl<'de> Deserialize<'de> for ImpulsiveManeuver
impl<'de> Deserialize<'de> for ImpulsiveManeuver
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ImpulsiveManeuver
impl Display for ImpulsiveManeuver
Sourceimpl PartialEq for ImpulsiveManeuver
impl PartialEq for ImpulsiveManeuver
Sourceimpl Serialize for ImpulsiveManeuver
impl Serialize for ImpulsiveManeuver
Sourceimpl StaticType for ImpulsiveManeuver
impl StaticType for ImpulsiveManeuver
Sourcefn static_type() -> SimpleType
fn static_type() -> SimpleType
Return the Dhall type that represents this type. Read more
impl Copy for ImpulsiveManeuver
impl StructuralPartialEq for ImpulsiveManeuver